aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-wol.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-wol.c')
-rw-r--r--epan/dissectors/packet-wol.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-wol.c b/epan/dissectors/packet-wol.c
index ef31f3b989..eec08b8cab 100644
--- a/epan/dissectors/packet-wol.c
+++ b/epan/dissectors/packet-wol.c
@@ -317,11 +317,11 @@ proto_reg_handoff_wol(void)
{
dissector_handle_t wol_handle;
/* Use new_create_dissector_handle() to indicate that dissect_wol()
* returns the number of bytes it dissected (or 0 if it thinks the packet
* does not belong to PROTONAME).
*/
- wol_handle = new_create_dissector_handle(dissect_wol, proto_wol);
+ wol_handle = create_dissector_handle(dissect_wol, proto_wol);
/* We don't really want to register with EVERY possible dissector,
* do we? I know that the AMD white paper specifies that the
@@ -317,11 +317,11 @@ proto_reg_handoff_wol(void)
{
dissector_handle_t wol_handle;
-/* Use new_create_dissector_handle() to indicate that dissect_wol()
+/* Use create_dissector_handle() to indicate that dissect_wol()
* returns the number of bytes it dissected (or 0 if it thinks the packet
* does not belong to PROTONAME).